@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Message::String;
-our $VERSION = '0.1.6'; # VERSION
+our $VERSION = '0.1.7'; # VERSION
 # ABSTRACT: A pragma to declare and organise messaging.
 use Clone           ( 'clone' );
 use DateTime        ();
@@ -1145,7 +1145,7 @@ Message::String - A pragma to declare and organise messaging.
 
 =head1 VERSION
 
-version 0.1.6
+version 0.1.7
 
 =head1 SYNOPSIS
 
@@ -1242,7 +1242,7 @@ packages. By including C<EXPORT> or C<EXPORT_OK> in the argument list,
 before your messages are listed, you can be sure that your package will
 export your symbols one way or the other.
 
-The examples below show how to exports using C<EXPORT> and C<EXPORT_OK>; they
+The examples below show how to export using C<EXPORT> and C<EXPORT_OK>; they
 also demonstrate how to define messages using less onerous string catalogues
 and, when doing so, how to split longer messages in order to keep the lengths
 of your lines manageable:
@@ -1439,8 +1439,8 @@ of messages is to be added to the listed tag group(s). Any necessary updates
 to the caller's C<%EXPORT_TAGS> hash and C<@EXPORT_OK> array are made. The
 explicit use of C<EXPORT_OK> is unnecessary since its use is implied.
  
-Tags may listed as separately or together in the same compound strings, 
-though must be prefixed with a colon (C<:>).
+Tags may be listed separately or together in the same string. Regardless of 
+how they are presented, each tag must start with a colon (C<:>).
 
     # Grouping messages with a single tag:
     #
@@ -1460,7 +1460,7 @@ though must be prefixed with a colon (C<:>).
 =back
 
 Tag groups and other export options have no effect if the calling package
-is called C<main::>.
+is C<main::>.
 
 If the calling package hasn't already been declared a subclass of C<Exporter>
 then the C<Exporter> package is loaded and the caller's C<@ISA> array will
@@ -1841,7 +1841,7 @@ C<to_string> method.
 
 =head1 MESSAGE TYPES
 
-Messages come in an nine great flavours, each identified by a single-letter 
+Messages come in nine great flavours, each identified by a single-letter 
 type code. A message's type represents the severity of the condition that
 would cause the message to be issued:
 
@@ -1863,7 +1863,7 @@ would cause the message to be issued:
 =head2 How messages are assigned a type
 
 When a message is defined an attempt is made to discern its type by examining
-it for a series of clues:
+it for a series of clues in the message's identifier:
 
 =over
 
@@ -1903,13 +1903,12 @@ L<Long Type Codes>).
 
 =head3 Long Type Codes
 
-In addition to having a single-letter type code, longer type code aliase may
-be used to describe their types. In fact, the public interface often allows
-for the use of the longer type code aliases where a type code may be used
-for reasons of clarity.
+In addition to single-letter type codes, some longer aliases may under some
+circumstances be used in their stead. This can and does make some statements
+a little less cryptic.
 
 We can use one of this package's protected methods (C<_types_by_alias>) to
-not only list the type code aliases but to reveal type code equivalence:
+not only list the type code aliases but also reveal type code equivalence:
 
     use Test::More;
     use Data::Dumper::Concise;
@@ -2002,24 +2001,50 @@ change it back when you're done.
 
 =head2 Customising message output
 
+Examples shown below operate on a pragma level, which affects all messages.
+
+Any particular message may override any of these settings simply by replacing
+C<message> with C<I<MESSAGE_ID>>.
+
 =head3 Embedding timestamps
 
-    MESSAGE_ID->_default_timestamp_format($strftime_format_str);
-    MESSAGE_ID->_type_timestamp($type_str, '');
-    MESSAGE_ID->_type_timestamp($type_str, 1);
-    MESSAGE_ID->_type_timestamp($type_str, $strftime_format_str);
-    MESSAGE_ID->_type_timestamp('');
-    MESSAGE_ID->_type_timestamp(1);
+    # Get or set the default timestamp format
+    $strftime_format_strn = message->_default_timestamp_format;
+    message->_default_timestamp_format($strftime_format_str);
+    
+    # Don't embed time data in messages of specified type
+    message->_type_timestamp($type_str, '');
+
+    # Embed time data in messages of specified type, using default format
+    message->_type_timestamp($type_str, 1);
+    
+    # Embed time data in messages of specified type, using specified format
+    message->_type_timestamp($type_str, $strftime_format_str);
+
+    # Don't Embed time data in ANY message types.
+    message->_type_timestamp('');
+
+    # Embed time data in ALL message types, using default format
+    message->_type_timestamp(1);
     
 =head3 Embedding type information
 
-    MESSAGE_ID->_type_tlc($type_str, '');
-    MESSAGE_ID->_type_tlc($type_str, $three_letter_code_str);
+    # Embed no additional type info in messages of a type
+    message->_type_tlc($type_str, '');
 
+    # Embed additional type info in messages of a type (3-letters max)
+    message->_type_tlc($type_str, $three_letter_code_str);
+
+    # Example
+    message->_type_tlc('I', 'INF');
+    
 =head3 Embedding the message id
 
-    MESSAGE_ID->_type_id($type_str, $bool);
-    MESSAGE_ID->_type_id($bool);
+    # Embed or don't embed message ids in a type of message 
+    message->_type_id($type_str, $bool);
+    
+    # Embed or don't embed message ids in all types of message 
+    message->_type_id($bool);
 
 =head1 REPOSITORY
 
